==> format_tiles_moodle45_2025070355.zip: tiles/README.md <==
# Tiles Course Format

### Author: David Watson http://evolutioncode.uk

This is the "Tiles" course format plugin for Moodle.

## Installation and Use
This plugin should be installed in a sub directory of /course/format/ called tiles

Once installed:

- it will be available for an editing teacher to select as the format for a given course under Course Administration > Edit Settings > Course Format

- if this is done, the format will be displayed to a user when they enter that course (as student or teacher)

- an Administrator will be able to see the plugins settings under Site Administration > Plugins > Course Formats > Tiles

## Branches

At the time of writing (July 2025) the following branches were being maintained:

| Moodle version | Tiles branch    |
|----------------|-----------------|
| 4.5 LTS        | moodle45        |
| 5.0            | master/moodle50 |

The following branches are in the repo but are no longer receiving updates:

| Moodle version  | Tiles branch    |
|-----------------|-----------------|
| 4.0             | moodle41b*      |
| 4.1 LTS         | moodle41b*      |
| 4.2             | moodle42b       |
| 4.3             | moodle43        |
| 4.4             | moodle44        |

(*The moodle41 branch was used for both Moodle 4.0 and 4.1)

## Compatibility and Support
This version of the plugin is compatible with the Moodle version specified in the plugin's version.php file (under $plugin->supported).  Other versions are available for prior versions of Moodle.

It supports the Privacy API.

It is intended to support the current versions of the most popular browsers such as Chrome, Firefox, desktop Safari and mobile iOS and Android.

## Licence
This plugin is part of Moodle - http://moodle.org/

Moodle is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

Moodle is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with Moodle.  If not, see http://www.gnu.org/licenses

Icons: some icons are custom to this plugin, but the majority are from Font Awesome version 4.7 under License SIL OFL 1.1.  See https://fontawesome.com/license and specifically https://fontawesome.com/v4.7.0/license

==> format_tiles_moodle51_2026012570.zip: tiles/README.md <==
# Tiles Course Format

### Author: David Watson http://evolutioncode.uk

This is the "Tiles" course format plugin for Moodle.

## Installation and Use
This plugin should be installed in a sub directory of /course/format/ called tiles

Once installed:

- it will be available for an editing teacher to select as the format for a given course under Course Administration > Edit Settings > Course Format

- if this is done, the format will be displayed to a user when they enter that course (as student or teacher)

- an Administrator will be able to see the plugins settings under Site Administration > Plugins > Course Formats > Tiles

## Branches

At the time of writing (October 2025) the following branches were being maintained:

| Moodle version | Tiles branch    |
|----------------|-----------------|
| 4.5 LTS        | moodle45        |
| 5.0            | moodle50        |
| 5.1            | master/moodle51 |

The following branches are in the repo but are no longer receiving updates:

| Moodle version  | Tiles branch    |
|-----------------|-----------------|
| 4.0             | moodle41b*      |
| 4.1 LTS         | moodle41b*      |
| 4.2             | moodle42b       |
| 4.3             | moodle43        |
| 4.4             | moodle44        |

(*The moodle41 branch was used for both Moodle 4.0 and 4.1)

## Compatibility and Support
This version of the plugin is compatible with the Moodle version specified in the plugin's version.php file (under $plugin->supported).  Other versions are available for prior versions of Moodle.

It supports the Privacy API.

It is intended to support the current versions of the most popular browsers such as Chrome, Firefox, desktop Safari and mobile iOS and Android.

## Licence
This plugin is part of Moodle - http://moodle.org/

Moodle is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

Moodle is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with Moodle.  If not, see http://www.gnu.org/licenses

Icons: some icons are custom to this plugin, but the majority are from Font Awesome version 4.7 under License SIL OFL 1.1.  See https://fontawesome.com/license and specifically https://fontawesome.com/v4.7.0/license
